@@ -45,7 +45,7 @@ function bayesspam_filters(&$imap_stream, $use_mailbox=0) {
 	foreach ($boxes as $box) {
 		if ($GLOBALS['bayesspam_inboxonly'] != 1 || ($GLOBALS['bayesspam_inboxonly'] == 1 && preg_match("/^INBOX$/", $box['unformatted-dm']))) {
 			if (($use_mailbox == 1 && $box['unformatted-dm'] == $GLOBALS['mailbox'] && !in_array($box['unformatted-dm'],$GLOBALS['bayesspam_ignore_folders'])) || ($use_mailbox == 0 && !in_array($box['unformatted-dm'], $GLOBALS['bayesspam_ignore_folders']))) {
-				if (array_search('noselect', $box['flags']) === FALSE && !preg_match("/^INBOX\.Sent/", $box['unformatted-dm']) && sqimap_unseen_messages($imap_stream, $box['unformatted-dm']) > 0) {
+				if ( (array_search('noselect', $box['flags']) === FALSE || array_search('noselect', $box['flags']) === NULL) && !preg_match("/^INBOX\.Sent/", $box['unformatted-dm']) && sqimap_unseen_messages($imap_stream, $box['unformatted-dm']) > 0) {
 					$run_folders[] = $box['unformatted-dm'];
 				}
 			}
@@ -54,18 +54,19 @@ function bayesspam_filters(&$imap_stream, $use_mailbox=0) {
 
 	foreach ($run_folders as $box) {
 		$spam_messages = array();
-        $qty = sqimap_get_num_messages ($imap_stream, $box);
-        $id = range(1, $qty);
+		$qty = sqimap_get_num_messages ($imap_stream, $box);
+		$id = range(1, $qty);
 
 		$mbxresponse = sqimap_mailbox_select($imap_stream, $box);
 
 		$msgs_list = sqimap_get_small_header_list($imap_stream, $id, 0);
+		$flag_list = sqimap_get_flags_list($imap_stream, $id);
 
 		$which = 0;
 		$messages = array();
 		if (sizeof($msgs_list)){
 			foreach ($msgs_list as $hdr) {
-				if ($hdr->flag_seen != TRUE) {
+				if (array_search('Seen', $flag_list[$which]) === NULL || array_search('Seen', $flag_list[$which]) === FALSE) {
 					$messages[] = $id[$which];
 				}
 				$which++;
@@ -121,7 +122,7 @@ function bayesspam_filters(&$imap_stream, $use_mailbox=0) {
 		if ($spam_messages) {
 			$message_str = sqimap_message_list_squisher($spam_messages);
 			if ($GLOBALS['bayesspam_delete']) {
-				sqimap_run_command ($imap_stream, 'STORE $message_str +FLAGS (\Deleted)', true, $response, $message);
+				sqimap_run_command ($imap_stream, 'STORE '.$message_str.' +FLAGS (\Deleted)', true, $response, $message);
 			} elseif (sqimap_mailbox_exists($imap_stream, $GLOBALS['bayesspam_folder'])) {
 				sqimap_run_command ($imap_stream, 'COPY '.$message_str.' "'.$GLOBALS['bayesspam_folder'].'"', true, $response, $message);
 				sqimap_run_command ($imap_stream, 'STORE '.$message_str.' +FLAGS (\Deleted)', true, $response, $message);
